% CorrMaps1 16-Jan-2020 

% make correlation maps in the style of Fig 11.6 of Saarman et al

% circles with diameter proportional to r value

% treats correlations between 
%   survey OCzmax (77 stns) vs TimSer BottOC qh, hr, dy (11 stns)
%   survey OCmin  " "       vs " "
%   survey OPzmax (77 stns) vs TimSer BottOP " " 
%   survey OPmin  " "       vs " "
%   survey CHLzmin " "      vs TimSer SurfCHL " "
%   survey CHLmax " "       vs " " 

% for each of the above 18 param pairs make:
%   a 3-page series of plots
%       four frames on each page
%           each frame a map, results b/w 77 srv stns and one timser stn

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(infil);

npp = length(prmpairs);
fstnlst = fieldnames(TimSer);
nfstn = length(fstnlst);
nstn = length(STN.Stn);

% correlation calcs & fill results tables
for ipp = 1:npp
    % create param-pair name
    ppnam{ipp} = sprintf('%s_%s%s',prmpairs{ipp}{1},prmpairs{ipp}{2},...
    prmpairs{ipp}{3});
    % runtime print
    fprintf('%s (%d of %d)\n',ppnam{ipp},ipp,npp);
    % initialize tables for rho and pval
    eval(sprintf('%s.rho = table(STN.Stn);',ppnam{ipp}));
    eval(sprintf('%s.pval = table(STN.Stn);',ppnam{ipp}));
    % compute
    for ifstn = 1:nfstn
        % runtime print
        fprintf('   TimSer stn %s\n',fstnlst{ifstn});
        % add column to table for this ifstn
        eval(sprintf('%s.rho.%s = nan*ones(length(STN.Stn),1);',...
            ppnam{ipp},fstnlst{ifstn}));
        for istn = 1:nstn
            % get data
            ind = find( strcmp(WCOL.Stn,STN.Stn{istn}));
            eval(sprintf('srv = WCOL.%s(ind);',prmpairs{ipp}{1}));
            eval(sprintf('ts = TimSer.%s.%s.%s(ind);',fstnlst{ifstn},...
                prmpairs{ipp}{2},prmpairs{ipp}{3}));
            if (length(srv) > nmin & length(ts)  > nmin )
                if ( length(find(isnan(srv)))/length(srv) < frmin & ...
                    length(find(isnan(ts)))/length(ts) < frmin )
                    % compute and store rho and pval
                    ind = find(~isnan(srv) & ~isnan(ts));
                    [rh,pv] = corr(srv(ind),ts(ind));
                    eval(sprintf('%s.rho.%s(istn) = rh; ',...
                        ppnam{ipp},fstnlst{ifstn}));
                    eval(sprintf('%s.pval.%s(istn) = pv; ',...
                        ppnam{ipp},fstnlst{ifstn}));
                    clear rh pv;
                end
            end
            clear ind srv ts;
        end
    end
end
eval(sprintf('save dat/CorrMaps1_%s CHL* OC* OP*;',runname));

%% Plots
nfr = 4;
npg = ceil(length(fstnlst)/nfr);
frwid = 0.5*(1 - 3*hmrg); % unitless, fraction of 8.5in
frhgt = 0.5*(1 - 3*vmrg); % " " 11
% axes limits calc
fstnloc = load(fstnfil);
maxlon = nanmax([STN.Lon; fstnloc.lon]);
minlon = nanmin([STN.Lon; fstnloc.lon]);
maxlat = nanmax([STN.Lat; fstnloc.lat]);
minlat = nanmin([STN.Lat]); % exclude RWU
lonbuf = lonbuffrac*(maxlon - minlon);
tlonmax = maxlon+lonbuf;
tlonmin = minlon-lonbuf;
latbuf = latbuffrac*(maxlat - minlat);
tlatmax = maxlat+latbuf;
tlatmin = minlat-latbuf;
clear lonbuf latbuf maxlat minlat maxlon minlon;
kmperdeglat = 111.120;
kmperdeglon = kmperdeglat*cos(pi*mean([tlatmin tlatmax])/180);
kmhgt = (tlatmax-tlatmin)*kmperdeglat;
kmwid = (tlonmax-tlonmin)*kmperdeglon;
if frwid*8.5/(frhgt*11) < kmwid/kmhgt
    lonmin = tlonmin;
    lonmax = tlonmax;
    kmhgt = kmwid*(frhgt*11)/(frwid*8.5);
    latmin = mean([tlatmin tlatmax]) - 0.5*kmhgt/kmperdeglat;
    latmax = mean([tlatmin tlatmax]) + 0.5*kmhgt/kmperdeglat;
    clear tlatmin tlatmax;
else
    latmin = tlatmin;
    latmax = tlatmax;
    kmwid = kmhgt*(frwid*8.5)/(frhgt*11);
    lonmin = mean([tlonmin tlonmax]) - 0.5*kmwid/kmperdeglon;
    lonmax = mean([tlonmin tlonmax]) + 0.5*kmwid/kmperdeglon;
    clear tlonmin tlonmax;
end
clear kmperdeglat kmwid kmhgt;
lonmin = lonmin-lonoff;
lonmax = lonmax-lonoff;
cst = load(cstfil);
bathy = load(bathyfil);
bathy.z(isnan(bathy.z)) = 0;
ind = find(bathy.lat>latmin);
bathy.lat = bathy.lat(ind);
bathy.z = flipud(bathy.z);
bathy.z = flipud(bathy.z(ind,:));
clear ind;
bathy.z = -floor(-(bathy.z/3)*3);
for ipp = 1:npp
    afr = 0; % counter relative to all 11 frames
    fprintf('Param Pair %s\n',ppnam{ipp});
    for ipg = 1:npg % page number
        fh = figport('on');
        fprintf('   Page %d\n',ipg);
        for ifr = 1:nfr % 1 to 4 (frame number within page)
            afr = afr+1;
            fprintf('      Frame %d\n',ifr);
            if afr<=nfstn
                % bathy & coastline
                x0 = hmrg +  mod(ifr-1,2)*(hmrg+frwid);
                y0 = vmrg + (1-round(ifr/5))*(vmrg+frhgt);
                axes('position',[ x0 y0 frwid frhgt]);
                hold;
                imagesc(bathy.lon,flipud(bathy.lat),bathy.z);
                cm = colormap('gray');
                colormap(cm.^0.6);
                cb = colorbar('Location','manual','Position',... 
                    [x0+cbxo y0+cbyo cbw cbh],'Axislocation','in');
                cb.Label.String = 'meters';
                cb.Ticks = fliplr(-[0:3:max(-bathy.z(:))]);
                cb.TickLength = 0.076;
                % coast
                plot(cst.lon,cst.lat,'k');
                xlim([lonmin lonmax]);
                ylim([latmin latmax]);
                set(gca,'xtick',[],'xticklabel',[],...
                    'ytick',[],'yticklabel',[]);
                box on;
                % circles
                eval(sprintf('dat = %s.rho.%s;',ppnam{ipp},...
                    fstnlst{afr}));
                for istn = 1:nstn
                    if dat(istn) >= 0 % positive rho - blue circle
                        plot(STN.Lon(istn),STN.Lat(istn),'.b',...
                               'markersize',dat(istn)*cptsmax,...
                               'markerfacecolor','b');
                    else % negative rho - red circle
                        plot(STN.Lon(istn),STN.Lat(istn),'.r',...
                               'markersize',-dat(istn)*cptsmax,...
                               'markerfacecolor','r');
                    end
                end
                clear dat;
                % green star at fstn
                [~,ind] = ismember(fstnlst{afr},fstnloc.SiteAbbr);
                sh = scatter(fstnloc.lon(ind),fstnloc.lat(ind),...
                    'MarkerFaceColor','g','MarkerEdgeColor','g',...
                    'marker','p');
                sh.SizeData = stsiz;
                alpha(sh,alph);
                % title
                title(sprintf('%s',prmpairs{ipp}{4}),...
                    'interpreter','none');
                % legend for circles
                for i = -1:0.25:1
                    x = lonmax-leglonoff;
                    y = latmax-leglatoff+i*leglatincr;
                    if i >0
                        plot(x,y,'.b','markersize',i*cptsmax,...
                               'markerfacecolor','b');
                    elseif i <0
                        plot(x,y,'.r','markersize',-i*cptsmax,...
                               'markerfacecolor','r');
                    end
                    text(x,y,sprintf('  %+.2f',i));
                end
                text(x,y+0.25*leglatincr,'  rho');
                clear i;
                % legend for mooring
                x = x-1.85*leglonoff;
                y = y-0.5*leglatincr;
                if findstr('Bott',prmpairs{ipp}{2})                    
                    text(x,y,['  ' fstnlst{afr} ...
                    sprintf(' sensor\n %.1f m deep',fstnloc.zdp(ind))]);
                else
                    text(x,y,['  ' fstnlst{afr} ...
                    sprintf(' sensor\n %.1f m deep',fstnloc.zsh(ind))]);
                end
                sh = scatter(x,y,'MarkerFaceColor','g',...
                    'MarkerEdgeColor','g','marker','p');
                sh.SizeData = stsiz;
                alpha(sh,alph);
                clear ind;     
                % scale bar
                x = x-2*leglonoff;          
                errorbar(x+[-1.5 -0.5 0.5 1.5]/kmperdeglon,y*ones(4,1),...
                  ones(4,1)/kmperdeglon,'horizontal','color','k');
                text(x,y,'5 km','verticalalignment','top');
            end
        end
        eval(sprintf('print -dpng plt/%s-p%d;',ppnam{ipp},ipg));
        delete(gcf);
    end
    clear tfr;
end

% end of module
diary off;