% LaggedCorrCalc 17-Mar-2020 

% Computes and saves lagged correlations between daily-mean timeseries
% observations and spatial survey observations.

% VERY SLOW

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(datfil);

%% preparations

% Years
yrs = min(WCOL.Date.Year):max(WCOL.Date.Year);
nyr = length(yrs);

% Fixed site stations
fstns = DIST(1,79:end).Properties.VariableNames;
nfstn = length(fstns);
fstndat = load(fstnfil);
leglbls = {};
for ifstn = 1:nfstn
    ind = find(ismember(fstndat.SiteAbbr,fstns(ifstn)));
    leglbls{ifstn} = [ fstns{ifstn} sprintf(' depth %.1fm',...
        fstndat.zdp(ind))];
    clear ind;
end
clear fstndat, ifstn;

% Lags
lgs = -minmaxlag:minmaxlag; % 1-day increments
nlg = length(lgs);

% Param pairs
npp = length(prmpairs);
ppnam = {};
for ipp = 1:npp
    ppnam{ipp} = [prmpairs{ipp}{1} '_' prmpairs{ipp}{2}];
end

% survey stations
stns = STN.Stn;
nstn = length(stns);

% rslts table template
tmplt = table(STN.Stn);
for ilg = 1:nlg
    if lgs(ilg) > 0
        col = sprintf('Lp%02dd',abs(lgs(ilg)));
    elseif lgs(ilg) < 0
        col = sprintf('Lm%02dd',abs(lgs(ilg)));
    else
        col = 'L00d';
    end
    eval(sprintf('tmplt.%s = nan*ones(height(tmplt),1);',col));
end

%% Main loop
for ipp = 1:npp
    fprintf('Param pair %s (%d/%d)\n',ppnam{ipp},ipp,npp);
    for ifstn = 1:nfstn
        fprintf('  Fixed-site stn %s (%d/%d)\n',fstns{ifstn},ifstn,nfstn);
        % get all years' data from this fixed site
        fstnind = find(ismember(DAILY.Stn,fstns(ifstn)));
        allfstndat = DAILY(fstnind,{'Date';prmpairs{ipp}{2}});
        clear fstnind;
        rslt = tmplt;
        for istn = 1:nstn
            fprintf('    Srvy stn %s (%d/%d)\n',stns{istn},istn,nstn);
            % get srvy stn data values
            stnind = find(ismember(WCOL.Stn,stns(istn)));
            allstndat = WCOL(stnind,{'Date';prmpairs{ipp}{1}});
            clear stnind;
            for ilg = 1:nlg
                % fprintf('      Lag %ddy (%d/%d)\n',lgs(ilg),ilg,nlg);
                % initialize containers for pairs
                tsdat = [];
                srvdat = [];
                for iyr = 1:nyr
                    % fprintf('        Year %d of %d\n',iyr,nyr);
                    srvdates = allstndat(...
                        find(allstndat.Date.Year==yrs(iyr)),1).Variables;
                    if length(srvdates)
                        % keep survey dates that have non-nan values
                        srvvals = allstndat(...
                          find(allstndat.Date.Year==yrs(iyr)),2).Variables;
                        ind = ~isnan(srvvals);
                        srvvals = srvvals(ind);
                        srvdates = srvdates(ind);
                        clear ind;
                        if length(srvdates)
                            fdates = srvdates+lgs(ilg);
                            tsvals = allfstndat(find(ismember(...
                                allfstndat.Date,fdates)),2).Variables;
                            ind = ~isnan(tsvals);
                            tsdat = [tsdat; tsvals(ind);];
                            srvdat = [srvdat; srvvals(ind);];
                            clear ind;
                        end
                        clear srvvals;
                    end
                    clear srvdates;
                end
                clear iyr;
                % compute r using pairs from all years
                if length(srvdat) > nmin
                    cc = corrcoef(srvdat,tsdat,'rows','pairwise'); 
                    rho = cc(1,2);
                    rslt(istn,ilg+1) = {rho};
                    clear cc rho;
                end
                clear srvdat tsdat;
            end
            clear allstndat ilg;
            clear rho;
        end
        eval(sprintf('%s.%s = rslt;',ppnam{ipp},fstns{ifstn}));
        clear istn rslt allfstndat;
    end
    clear ifstn;
end
clear ipp;

str = sprintf('save dat/Lagged stns fstns lgs ppnam prmpairs %s ',ppnam{1});
for ipp = 2:npp
    str = [str ' ' ppnam{ipp}];
end
eval([str ';']);


% end of module
diary off;