% MapPlts 26-Feb-2020 

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

% meta info
load([indir sprintf('SpatCorr_meta_%s',inrun)]);
npp =length(ppnam);
nrstn = length(refstns);
load(datfil);

%% Plots
nfr = 4;
npg = 3;
frwid = 0.5*(1 - 3*hmrg); % unitless, fraction of 8.5in
frhgt = 0.5*(1 - 3*vmrg); % " " 11
% axes limits calc
fstnloc = load(fstnfil);
maxlon = nanmax([STN.Lon; fstnloc.lon]);
minlon = nanmin([STN.Lon; fstnloc.lon]);
maxlat = nanmax([STN.Lat; fstnloc.lat]);
minlat = nanmin([STN.Lat]); % exclude RWU
lonbuf = lonbuffrac*(maxlon - minlon);
tlonmax = maxlon+lonbuf;
tlonmin = minlon-lonbuf;
latbuf = latbuffrac*(maxlat - minlat);
tlatmax = maxlat+latbuf;
tlatmin = minlat-latbuf;
clear lonbuf latbuf maxlat minlat maxlon minlon;
kmperdeglat = 111.120;
kmperdeglon = kmperdeglat*cos(pi*mean([tlatmin tlatmax])/180);
kmhgt = (tlatmax-tlatmin)*kmperdeglat;
kmwid = (tlonmax-tlonmin)*kmperdeglon;
if frwid*8.5/(frhgt*11) < kmwid/kmhgt
    lonmin = tlonmin;
    lonmax = tlonmax;
    kmhgt = kmwid*(frhgt*11)/(frwid*8.5);
    latmin = mean([tlatmin tlatmax]) - 0.5*kmhgt/kmperdeglat;
    latmax = mean([tlatmin tlatmax]) + 0.5*kmhgt/kmperdeglat;
    clear tlatmin tlatmax;
else
    latmin = tlatmin;
    latmax = tlatmax;
    kmwid = kmhgt*(frwid*8.5)/(frhgt*11);
    lonmin = mean([tlonmin tlonmax]) - 0.5*kmwid/kmperdeglon;
    lonmax = mean([tlonmin tlonmax]) + 0.5*kmwid/kmperdeglon;
    clear tlonmin tlonmax;
end
clear kmperdeglat kmwid kmhgt;
lonmin = lonmin-lonoff;
lonmax = lonmax-lonoff;
cst = load(cstfil);
bathy = load(bathyfil);
bathy.z(isnan(bathy.z)) = 0;
ind = find(bathy.lat>latmin);
bathy.lat = bathy.lat(ind);
bathy.z = flipud(bathy.z);
bathy.z = flipud(bathy.z(ind,:));
clear ind;
bathy.z = -floor(-(bathy.z/3)*3);
for ipp = 1:npp
    fprintf('Param Pair %s (%d of %d) \n',ppnam{ipp},ipp,npp);
    load([indir sprintf('SpatCorr_%s_%s',inrun,ppnam{ipp})]);
    for ipg = 1:npg % page number
        fh = figport('on');
        fprintf('   Page %d\n',ipg);
        for ifr = 1:nfr % 1 to 4 (frame number within page)
            irstn = (ipg-1)*nfr + ifr;
            fprintf('      Frame %d\n',ifr);
            % bathy & coastline
            x0 = hmrg +  mod(ifr-1,2)*(hmrg+frwid);
            y0 = vmrg + (1-round(ifr/5))*(vmrg+frhgt);
            axes('position',[ x0 y0 frwid frhgt]);
            hold;
            imagesc(bathy.lon,flipud(bathy.lat),bathy.z);
            cm = colormap('gray');
            colormap(cm.^0.6);
            cb = colorbar('Location','manual','Position',... 
                [x0+cbxo y0+cbyo cbw cbh],'Axislocation','in');
            cb.Label.String = 'meters';
            cb.Ticks = fliplr(-[0:3:max(-bathy.z(:))]);
            cb.TickLength = 0.076;
            clear cb x0 y0;
            % coast
            plot(cst.lon,cst.lat,'k');
            xlim([lonmin lonmax]);
            ylim([latmin latmax]);
            set(gca,'xtick',[],'xticklabel',[],...
                'ytick',[],'yticklabel',[]);
            box on;
            % circles (not boilerplate)
            eval(sprintf('dat = %s.rho.%s;',ppnam{ipp},refstns{irstn}));
            for istn = 1:nstn
                if  istn <= 57
                    % isempty(find(ismember(meta.STNindLessThan4m,istn)))
                    if ~strcmp(STN.Stn{istn},refstns{irstn})
                        if ~isnan(dat(istn))
                            if dat(istn) >= 0 % positive rho - blue circle
                                plot(STN.Lon(istn),STN.Lat(istn),'.b',...
                                       'markersize',dat(istn)*cptsmax,...
                                       'markerfacecolor','b');
                            else % negative rho - red circle
                                plot(STN.Lon(istn),STN.Lat(istn),'.r',...
                                       'markersize',-dat(istn)*cptsmax,...
                                       'markerfacecolor','r');
                            end
                        end
                    else
                        irefstn = istn;
                    end
                end
            end
            clear dat;
            % green star at refstn
            sh = scatter(STN.Lon(irefstn),STN.Lat(irefstn),...
                'MarkerFaceColor','g','MarkerEdgeColor','g',...
                'marker','p');
            sh.SizeData = stsiz;
            alpha(sh,alph);
            clear sh;                  
            % title
            title(sprintf('%s',prmpairs{ipp}{3}),'interpreter','none');
            % legend for circles
            for i = -1:0.25:1
                x = lonmax-leglonoff;
                y = latmax-leglatoff+i*leglatincr;
                if i >0
                    plot(x,y,'.b','markersize',i*cptsmax,...
                           'markerfacecolor','b');
                elseif i <0
                    plot(x,y,'.r','markersize',-i*cptsmax,...
                           'markerfacecolor','r');
                end
                text(x,y,sprintf('  %+.2f',i));
            end
            text(x,y+0.25*leglatincr,'  rho');
            clear i;
            % legend for refstn
            x = x-1.85*leglonoff;
            y = y-0.5*leglatincr;
            sh = scatter(x,y,'MarkerFaceColor','g',...
                'MarkerEdgeColor','g','marker','p');
            sh.SizeData = stsiz;
            alpha(sh,alph);
            text(x,y,sprintf(' Reference\n %s\n bathy %.1fm',...
               refstns{irstn},STN.zmaxMedn(irefstn)),'interpreter','none');
            clear irefstn;
            % scale bar
            x = x-2*leglonoff;          
            errorbar(x+[-1.5 -0.5 0.5 1.5]/kmperdeglon,y*ones(4,1),...
              ones(4,1)/kmperdeglon,'horizontal','color','k');
            text(x,y,'5 km','verticalalignment','top');
            clear x y;
        end
         clear ifr;
        eval(sprintf('print -dpng plt/%s-p%d;',ppnam{ipp},ipg));
        delete(gcf);
    end
    clear ipg fh tfr;
    eval(sprintf('clear %s;',ppnam{ipp}));
end
clear ipp;

% end of module
diary off;