% Scat 20-Mar-2020 

% (first, plot the raw pct area data as a simple timeseries)

% scatterplots/regressions using individual surveys (71 of them), showing 
%       the 3 Pct Area metrics (lt1p4, Lt2p9, Lt4p8)
%       vs
%       various quantities from the time series dataset:
%           avg DO at indiv stns

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(datfil);

%% initial basic "timeseries" plot of percent area metrics
figland('on');
axes;
hold;
set(gca,'xlim',[0.5 71.5]);
set(gca,'ylim',[0 100]);
box on;
grid on;
title('Pct Area Bottom DO less than 1.4 (red), 2.9 (blue), and 4.8 (green) mg/l');
ylabel('Percent');
yrs = unique(PctHypArea.Date.Year);
allyr = PctHypArea.Date.Year;
xtcks = [];
for iyr = 1:length(yrs)
    ind = find(allyr==yrs(iyr));
    x1 = min(ind)-0.5;
    x2 = max(ind)+0.5;
    plot([x1 x1],[0 100],'k');
    plot([x2 x2],[0 100],'k');
    xtcks = [xtcks mean([x1 x2])];
    plot(ind,PctHypArea.PctLt1p4(ind),'r');
    plot(ind,PctHypArea.PctLt1p4(ind),'rs','markerfacecolor','r');
    plot(ind,PctHypArea.PctLt2p9(ind),'b');
    plot(ind,PctHypArea.PctLt4p8(ind),'g');
    plot(ind,PctHypArea.PctLt2p9(ind),'bs','markerfacecolor','b');
    plot(ind,PctHypArea.PctLt4p8(ind),'gs','markerfacecolor','g');
    clear x1 x2 ind;
end
set(gca,'xtick',xtcks);
set(gca,'xticklabels',yrs);

print -dpng plt/PctAreas;
delete(gcf);
clear xtcks allyr yrs iyr;

%% now the scatter plots - using dailymean
fstns = DIST(1,79:end).Properties.VariableNames;
nfstn = length(fstns);

tabdat = nan*ones(nfstn,6);

dates = unique(TimSer.BR.BottOC.Date);
figport('on');
for ifstn = 1:nfstn
    subplot(4,3,ifstn);
    x = [];
    for idate = 1:length(dates)
        eval(sprintf('ind = min(find(TimSer.%s.BottOC.Date==dates(idate)));',...
            fstns{ifstn}));
        eval(sprintf('x = [x TimSer.%s.BottOC.dy(ind)];',fstns{ifstn}));
        clear ind;
    end
    titl = '';
    plot(x,PctHypArea.PctLt1p4,'rs','markerfacecolor','r');
    hold;
    eval(sprintf('rtab.%s = nan*ones(1,6);',fstns{ifstn}));
    mdl = fitlm(x,PctHypArea.PctLt1p4);
    titl = [titl sprintf(' Rr%s/p%s',...
        strrep(sprintf('%.2f',mdl.Rsquared.Ordinary), '0.', '.'),...
        strrep(sprintf('%.2f',mdl.Coefficients.pValue(2)), '0.', '.'))];
    tabdat(ifstn,1) = mdl.Rsquared.Ordinary;
    tabdat(ifstn,2) = mdl.Coefficients.pValue(2);    
    plot(x,PctHypArea.PctLt2p9,'bs','markerfacecolor','b');
    mdl = fitlm(x,PctHypArea.PctLt2p9);
    titl = [titl sprintf(' Br%s/p%s',...
        strrep(sprintf('%.2f',mdl.Rsquared.Ordinary), '0.', '.'),...
        strrep(sprintf('%.2f',mdl.Coefficients.pValue(2)), '0.', '.'))];
    tabdat(ifstn,3) = mdl.Rsquared.Ordinary;
    tabdat(ifstn,4) = mdl.Coefficients.pValue(2);    
    plot(x,PctHypArea.PctLt4p8,'gs','markerfacecolor','g');
    mdl = fitlm(x,PctHypArea.PctLt4p8);
    titl = [titl sprintf(' Gr%s/p%s',...
       strrep(sprintf('%.2f',mdl.Rsquared.Ordinary), '0.', '.'),...
        strrep(sprintf('%.2f',mdl.Coefficients.pValue(2)), '0.', '.'))];
    tabdat(ifstn,5) = mdl.Rsquared.Ordinary;
    tabdat(ifstn,6) = mdl.Coefficients.pValue(2);    
    grid on;
    box on;
    set(gca,'xlim',[0 10]);
    set(gca,'ylim',[0 100]);
    if ifstn == 11
        xlabel('Daily-mean D.O. [mg/l]');
    end
    if ifstn == 4
        ylabel('Pct area < 1.4(r), 2.9(b), 4.8(g) mg/l');
    end
    text(8.5,95,fstns{ifstn});
    % title(titl);
    clear x titl mdl;
end
% clear dates ifstn;
print -dpng plt/IndivStnDailyMn;
delete(gcf);

input = [["rsq1p4", "double"]; ...
		 ["pval1p4", "double"]; ...
         ["rsq2p9", "double"]; ...
		 ["pval2p9", "double"]; ...
         ["rsq4p8", "double"]; ...
		 ["pval4p8", "double"];];
tabl = array2table(round(tabdat,2),'RowNames',fstns,...
    'VariableNames',input(:,1));

%% scatterplots again but using daily def-dur
tabdat = nan*ones(nfstn,6);

figport('on');
for ifstn = 1:nfstn
    subplot(4,3,ifstn);
    x1p4 = [];
    x2p9 = [];
    x4p8 = [];
    for idate = 1:length(dates)
        eval(sprintf(['ind = find(DAILY.Date==dates(idate) & '...
            'ismember(DAILY.Stn,''%s''));'],fstns{ifstn}));
        if isempty(ind)
            x1p4 = [x1p4 nan];
            x2p9 = [x2p9 nan];
            x4p8 = [x4p8 nan];            
        else
            x1p4 = [x1p4 DAILY(ind,4).Variables];
            x2p9 = [x2p9 DAILY(ind,5).Variables];
            x4p8 = [x4p8 DAILY(ind,6).Variables];
        end
        clear ind;
    end
    titl = '';
    plot(x1p4,PctHypArea.PctLt1p4,'rs','markerfacecolor','r');
    hold;
    eval(sprintf('rtab.%s = nan*ones(1,6);',fstns{ifstn}));
    mdl = fitlm(x1p4,PctHypArea.PctLt1p4);
    titl = [titl sprintf(' Rr%s/p%s',...
        strrep(sprintf('%.2f',mdl.Rsquared.Ordinary), '0.', '.'),...
        strrep(sprintf('%.2f',mdl.Coefficients.pValue(2)), '0.', '.'))];
    tabdat(ifstn,1) = mdl.Rsquared.Ordinary;
    tabdat(ifstn,2) = mdl.Coefficients.pValue(2);    
    plot(x2p9,PctHypArea.PctLt2p9,'bs','markerfacecolor','b');
    mdl = fitlm(x2p9,PctHypArea.PctLt2p9);
    titl = [titl sprintf(' Br%s/p%s',...
        strrep(sprintf('%.2f',mdl.Rsquared.Ordinary), '0.', '.'),...
        strrep(sprintf('%.2f',mdl.Coefficients.pValue(2)), '0.', '.'))];
    tabdat(ifstn,3) = mdl.Rsquared.Ordinary;
    tabdat(ifstn,4) = mdl.Coefficients.pValue(2);    
    plot(x4p8,PctHypArea.PctLt4p8,'gs','markerfacecolor','g');
    mdl = fitlm(x4p8,PctHypArea.PctLt4p8);
    titl = [titl sprintf(' Gr%s/p%s',...
       strrep(sprintf('%.2f',mdl.Rsquared.Ordinary), '0.', '.'),...
        strrep(sprintf('%.2f',mdl.Coefficients.pValue(2)), '0.', '.'))];
    tabdat(ifstn,5) = mdl.Rsquared.Ordinary;
    tabdat(ifstn,6) = mdl.Coefficients.pValue(2);    
    grid on;
    box on;
    set(gca,'xlim',[0 5]);
    set(gca,'ylim',[0 100]);
    if ifstn == 11
        xlabel('Daily Def-Dur [mg l^{-1} dy] rel 1.4(r), 2.9(b), 4.8(g) mg/l ');
    end
    if ifstn == 4
        ylabel('Pct area < 1.4(r), 2.9(b), 4.8(g) mg/l');
    end
    text(4.25,95,fstns{ifstn});
    % title(titl);
    clear x titl mdl;
end
% clear dates ifstn;
print -dpng plt/IndivStnDefDur;
delete(gcf);

input = [["rsq1p4", "double"]; ...
		 ["pval1p4", "double"]; ...
         ["rsq2p9", "double"]; ...
		 ["pval2p9", "double"]; ...
         ["rsq4p8", "double"]; ...
		 ["pval4p8", "double"];];
tabl = array2table(round(tabdat,2),'RowNames',fstns,...
    'VariableNames',input(:,1));

% end of module
diary off;