% SpatCorrCalc 19-Feb-2020 

% Treats spatial correlations (no timeseries obs used) between survey: 
%   OCzmax @ 12 ref stns  - vs - OCzmax @ other 76 stns
%   " "                   - vs - OCmin @ other 76 stns
%   OCmin @ 12 ref stns   - vs - OCmin @ other 76 stns
%   " "                   - vs - OCzmax @ other 76 stns
%   OPzmax @ 12 ref stns  - vs - OPzmax @ other 76 stns
%   " "                   - vs - OPmin @ other 76 stns
%   OPmin @ 12 ref stns   - vs - OPmin @ other 76 stns
%   " "                   - vs - OPzmax @ other 76 stns
%   CHLzmin @ 12 ref stns - vs - CHLzmin @ other 76 stns
%   " "                   - vs - CHLmax @ other 76 stns
%   CHLmax @ 12 ref stns  - vs - CHLmax @ other 76 stns
%   " "                   - vs - CHLzmin @ other 76 stns

% Correlation calcs use same-day observations (no time information)

% For 12 specific reference srvy stations, plot:
%       A map with rho values as circles at all other 76 srvy stns
%           (circle diameter proportional to rho)
% And plot one x-y plot with rho vs (distance b/w stations)
%   Twelve symbol colors/styles: one per reference station

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(infil);
npp = length(prmpairs);
nstn = length(STN.Stn);
nrstn = length(refstns);
% correlation calcs & fill results tables
for ipp = 1:npp
    % create param-pair name
    ppnam{ipp} = sprintf('%s_%s',prmpairs{ipp}{1},prmpairs{ipp}{2});
    % runtime print
    fprintf('%s (%d of %d)\n',ppnam{ipp},ipp,npp);
    % init tables: rho, pval, n_refval, fr_refval, n_stnval, fr_stnval
    eval(sprintf('%s.rho = table(STN.Stn);',ppnam{ipp}));
    eval(sprintf('%s.pval = table(STN.Stn);',ppnam{ipp}));
    eval(sprintf('%s.n_ref = table(STN.Stn);',ppnam{ipp}));
    eval(sprintf('%s.fr_ref = table(STN.Stn);',ppnam{ipp}));
    eval(sprintf('%s.n_stn = table(STN.Stn);',ppnam{ipp}));
    eval(sprintf('%s.fr_stn = table(STN.Stn);',ppnam{ipp}));
    for irstn = 1:nrstn
        % runtime print
        fprintf('   Ref Stn %s (%d of %d)\n',refstns{irstn},irstn,nrstn);
        % add column to table for this refstn
        eval(sprintf('%s.rho.%s = nan*ones(length(STN.Stn),1);',...
            ppnam{ipp},refstns{irstn}));
        % get dates the ref station was sampled, and its values
        ind = find( strcmp(WCOL.Stn,refstns{irstn}) & ...
            datenum(WCOL.Date)>=datenum(datebeg) & ...
                datenum(WCOL.Date)<=datenum(dateend) );
        dates = WCOL.Date(ind); % all dates at refstn
        eval(sprintf('refvals = WCOL.%s(ind);',prmpairs{ipp}{1}));
        clear ind;
        for istn = 1:nstn
            stnvals = nan*ones(length(dates),1);
            for idate = 1:length(dates)
                ind = find(strcmp(WCOL.Stn,STN.Stn{istn}) & ...
                        WCOL.Date==dates(idate) );
                if length(ind)
                    eval(sprintf('stnvals(idate) = WCOL.%s(ind);',...
                        prmpairs{ipp}{2}));
                end
                clear ind;
            end
            n_stnval = length(stnvals);
            n_refval = length(refvals);
            fr_stnval = length(find(~isnan(stnvals)))/length(stnvals);
            fr_refval = length(find(~isnan(refvals)))/length(refvals);
            eval(sprintf('%s.n_ref.%s(istn) = n_refval; ',...
                        ppnam{ipp},refstns{irstn}));
            eval(sprintf('%s.fr_ref.%s(istn) = fr_refval; ',...
                        ppnam{ipp},refstns{irstn}));
            eval(sprintf('%s.n_stn.%s(istn) = n_refval; ',...
                        ppnam{ipp},refstns{irstn}));
            eval(sprintf('%s.fr_stn.%s(istn) = fr_refval; ',...
                        ppnam{ipp},refstns{irstn}));
            if ( n_stnval >= nmin & n_refval >= nmin )
                if ( fr_stnval >= frmin & fr_refval >= frmin )
                    % compute and store rho and pval
                    ind = find(~isnan(refvals) & ~isnan(stnvals));
                    [rh,pv] = corr(refvals(ind),stnvals(ind));
                    clear ind;
                    eval(sprintf('%s.rho.%s(istn) = rh; ',...
                        ppnam{ipp},refstns{irstn}));
                    eval(sprintf('%s.pval.%s(istn) = pv; ',...
                        ppnam{ipp},refstns{irstn}));
                    clear rh pv;
                end
            end
            clear stnvals;
        end
        clear istn dates refvals;
    end
    eval(sprintf('save dat/SpatCorr_%s_%s %s;',...
                runname,ppnam{ipp},ppnam{ipp}));
end
eval(sprintf('save dat/SpatCorr_meta_%s ppnam prmpairs refstns nstn;',...
    runname));

% end of module
diary off;