% SrvTmprl 19-Mar-2020 

% makes plots to help gauge how respresentative the survey sampling dates 
%   are, relative to all dates (i.e. what the timeseries msmts sample)

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(datfil,'DAILY','WCOL','DIST');

fstns = DIST(1,79:end).Properties.VariableNames;

nfstn = length(fstns);

srvdates = unique(WCOL.Date);
BinEdges = [0:9];
clear WCOL DIST;

if limitdates == 1
    yrs = unique(DAILY.Date.Year);
    nyr = length(yrs);
    srvst = [];
    srvfn = [];
    for iyr = 1:nyr
        ind = find(srvdates.Year==yrs(iyr));
        srvst = [srvst; srvdates(ind(1));];
        srvfn = [srvfn; srvdates(ind(end));];
    end
    incl = [];
    for i=1:height(DAILY)
        iyr = DAILY.Date(i).Year-2004;
        if DAILY.Date(i) >= srvst(iyr) & DAILY.Date(i) <= srvfn(iyr)
            incl = [incl; i];
        end
    end
    DAILY = DAILY(incl,:);
end

figport('on');
for ifstn = 1:nfstn
    % DO values on survey dates
    ind = find(ismember(DAILY.Date,srvdates) & ...
                                ismember(DAILY.Stn,fstns{ifstn}));
    srvvals = DAILY(ind,3).Variables;
    clear ind;
    % oxygen values on all dates
    ind = find(ismember(DAILY.Stn,fstns{ifstn}));
    allvals = DAILY(ind,3).Variables;
    clear ind;            
    % plot
    subplot(4,3,ifstn);
    yyaxis left;
    histogram(allvals,'BinEdges',BinEdges);
    if ifstn > 9
        xlabel('DO [mg/l]');
    end
    % ylabel('freq');
    yyaxis right;
    histogram(srvvals,'BinEdges',BinEdges);
    tst = kstest2(srvvals,allvals);
    if tst == 1
        str = 'diff';
    else
        str = 'same';
    end
    yyaxis left;
    text(0.8,0.9,fstns{ifstn},'units','normalized');
    text(0.8,0.8,str,'units','normalized','fontsize',8);
    clear str tst srvvals allvals; 
end
if limitdates==1
    print -dpng plt/BottDO_dateslim;
else
    print -dpng plt/BottDO;
end
delete(gcf);

BinEdges = [0:4:36];
figport('on');
for ifstn = 1:nfstn
    % DO values on survey dates
    ind = find(ismember(DAILY.Date,srvdates) & ...
                                ismember(DAILY.Stn,fstns{ifstn}));
    srvvals = DAILY(ind,7).Variables;
    clear ind;
    % oxygen values on all dates
    ind = find(ismember(DAILY.Stn,fstns{ifstn}));
    allvals = DAILY(ind,7).Variables;
    clear ind;
    % plot
    subplot(4,3,ifstn);
    yyaxis left;
    histogram(allvals,'BinEdges',BinEdges);
    xlabel('CHL [ug/l]');
    % ylabel('freq');
    yyaxis right;
    histogram(srvvals,'BinEdges',BinEdges);
    % ylabel('freq');
    if ifstn == 2
        title('Surf CHL histogram: all dates (blue/left) / survey dates only (orange/right)');
    end
    tst = kstest2(srvvals,allvals);
    if tst == 1
        str = 'diff';
    else
        str = 'same';
    end
    yyaxis left;
    ylabel([fstns{ifstn} sprintf('  ( KS: %s )',str)],'color','k');
    clear str tst srvvals allvals; 
end
if limitdates == 1
    print -dpng plt/SurfCHL_dateslim;
else
    print -dpng plt/SurfCHL;
end
delete(gcf);

% end of module
diary off;