% TemporalCorr1 12-Mar-2020 

% Lagged autocorrelations - one plt, 11 curves on it (one per fstn)

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(datfil);

yrs = min(WCOL.Date.Year):max(WCOL.Date.Year);
nyr = length(yrs);

stns = DIST(1,79:end).Properties.VariableNames;
nstn = length(stns);

fstndat = load(fstnfil);
leglbls = {};
for istn = 1:nstn
    ind = find(ismember(fstndat.SiteAbbr,stns(istn)));
    leglbls{istn} = [ stns{istn} sprintf(' depth %.1fm',...
        fstndat.zdp(ind))];
    clear ind;
end
clear fstndat;

lgs = -minmaxlag:minmaxlag; % 1-day increments
nlg = length(lgs);

stys = {'-';'--';':';'-.'};
stys = [stys' stys' stys' stys' stys' stys'];
clrs = {'c';'k';'r';'b';'g';'m'};
clrs = [clrs' clrs' clrs' clrs'];

prms = DAILY(1,3:end).Properties.VariableNames;
nprm = length(prms);

for iprm = 1:nprm
    figland('on');
    axes;
    hold;
    for istn = 1:nstn
        % fprintf('istn %d\n',istn);
        rho = nan*ones(1,nlg);
        % compute lagged autocorrelation rho values
        ind = ismember(DAILY.Stn,stns{istn});
        allyr = DAILY(ind,{'Date';prms{iprm}});
        clear ind;
        for ilg = 1:nlg
            % fprintf(' ilg %d\n',ilg);
            dat0 =[];
            datlg =[]; 
            for iyr = 1:nyr
                % fprintf('  iyr %d\n',iyr);
                dat = allyr(find(allyr.Date.Year==yrs(iyr)),2).Variables;
                if any(~isnan(dat))
                    if lgs(ilg) > 0
                        dat0 = [dat0; dat(1:(end-abs(lgs(ilg))));];
                        datlg = [datlg; dat((1+abs(lgs(ilg))):end);];
                    elseif lgs(ilg) < 0
                        dat0 = [dat0; dat((1+abs(lgs(ilg))):end);];
                        datlg = [datlg; dat(1:(end-abs(lgs(ilg))));];
                    else
                        dat0 = [dat0; dat;];
                        datlg = [datlg; dat;];
                    end
                end
                clear dat;
            end
            cc = corrcoef(dat0,datlg,'rows','pairwise'); 
            rho(ilg) = cc(1,2);
            clear cc iyr;
        end
        clear allyr ilg;
        lh(istn) = plot(lgs,rho,[clrs{istn} stys{istn}]);
        clear rho;
    end
    clear istn;

    xlim([-minmaxlag minmaxlag]);
    ylim([0 1]);
    title(sprintf('Lagged autocorrelation: %s',prms{iprm}));
    grid on;
    legend(lh,leglbls,'Location','best');
    clear lh;
    xlabel('days lag');
    ylabel('r');
    set(gcf,'PaperOrientation','Portrait');
    eval(sprintf('print -dpng plt/%s;',prms{iprm}));
    delete(gcf);
end

% end of module
diary off;