% TimserSptl 19-Mar-2020 

% histogram of srvy values at all srvy stations vs histogram of values at 
%   only the 11 srvy stations located closest to the fixed site locations

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

load(datfil,'DAILY','WCOL','DIST');

fstns = DIST(1,79:end).Properties.VariableNames;
fstns = fstns([7 1:4 11 6 10 5 8:9]);
nfstn = length(fstns);

% determine the 11 srvy stns closest to the fixed site locations
rstns = {};
for ifstn = 1:nfstn
    eval(sprintf('all = DIST.%s;',fstns{ifstn}));
    ind = find(all==min(all));
    rstns(ifstn) = DIST(ind,1).Variables;
    clear all;
end

Oallvals = WCOL.OCzmax;
ind = find(ismember(WCOL.Stn,rstns));
Orstnvals = WCOL.OCzmax(ind);
Callvals = WCOL.CHLzmin;
Crstnvals = WCOL.CHLzmin(ind);

figport('on');
subplot(2,1,1);
yyaxis left;
histogram(Oallvals,'BinEdges',[0:9]);
yyaxis right;
histogram(Orstnvals,'BinEdges',[0:9]);
xlabel('DO [mg/l]');
tst = kstest2(Oallvals,Orstnvals);
if tst == 1
    title('Spatial Surveys, Bottom DO histogram (KS: diff)');
else
    title('Spatial Surveys, Bottom DO histogram (KS: same)');
end
yyaxis left;
ylabel('All srvy stns');
yyaxis right;
ylabel('11 Srvy stns nearest fixed sites');

subplot(2,1,2);
yyaxis left;
histogram(Callvals,'BinEdges',[0:4:36]);
yyaxis right;
histogram(Crstnvals,'BinEdges',[0:4:36]);
xlabel('Chl [ug/l]');
tst = kstest2(Callvals,Crstnvals);
if tst == 1
    title('Spatial Surveys, Surface CHL histogram (KS: diff)');
else
    title('Spatial Surveys, Surface CHL histogram (KS: same)');
end
yyaxis left;
ylabel('All srvy stns');
yyaxis right;
ylabel('11 Srvy stns nearest fixed sites');

print -dpng plt/TimserSptl;
delete(gcf);

% end of module
diary off;