% basicmap 03-Jan-2020 

% table of survey number start/stop/missing, zmax ranges, and zbathy
% also map view (not as useful)

% plots of station ranks

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% for each stn, determine 1st/last survey and number missing between them
load(datfil);
srvlst = aux.srvlst;
grplst = aux.grplst;
maxgrplen = 0;
for i = 1:length(grplst)
    if length(grplst{i}) > maxgrplen
        maxgrplen = length(grplst{i});
    end
end

stnlst = STN.Stn;
nstn = length(stnlst);
firstsrvind = nan*ones(nstn,1);
lastsrvind = nan*ones(nstn,1);
missingsrvind = nan*ones(nstn,1);
for istn = 1:nstn
    allind = find(strcmp(WCOL.Stn,stnlst(istn)));
    firstsrvind(istn) = find(srvlst==WCOL.Date(allind(1)));
    lastsrvind(istn) = find(srvlst==WCOL.Date(allind(end)));
    missingsrvind(istn) = (lastsrvind(istn)-firstsrvind(istn)+1) ...
                            - length(allind);
end
clear istn;

ngrp = length(grplst);

% get bathy depths, in 14x14 cell array like table to show in plots
Cbathy = cell(ngrp,maxgrplen);
b = load(bathyfil);
b.z(isnan(b.z)) = 0;
for igrp = 1:ngrp
    ngstn = length(grplst{igrp});
    for istn = 1:ngstn
        ind = find(strcmp(STN.Stn,grplst{igrp}{istn}));
        zbathy = interp2(b.lon,flipud(b.lat),b.z,...
            STN.Lon(ind),STN.Lat(ind));
        Cbathy{igrp,istn} = sprintf(' %.1f',-zbathy);
        clear ind zbathy;
    end
    clear ngstn;
end
clear b;
% now same for zmaxMedn, zmaxMin, zmaxMax
Czmax = cell(ngrp,maxgrplen);
for igrp = 1:ngrp
    ngstn = length(grplst{igrp});
    for istn = 1:ngstn
        ind = find(strcmp(STN.Stn,grplst{igrp}{istn}));
        Czmax{igrp,istn} = sprintf(' %.1f(%.1f-%.1f)',...
            STN.zmaxMedn(ind),STN.zmaxMin(ind),STN.zmaxMax(ind));
        clear ind;
    end
    clear ngstn;
end
% now same for survey number range/missing
Csrv = cell(ngrp,maxgrplen);
for igrp = 1:ngrp
    ngstn = length(grplst{igrp});
    for istn = 1:ngstn
        ind = find(strcmp(STN.Stn,grplst{igrp}{istn}));
        Csrv{igrp,istn} = sprintf(' %d-%d(-%d)',...
            firstsrvind(ind),lastsrvind(ind),missingsrvind(ind));
        clear ind;
    end
    clear ngstn;
end
% put Cbathy, Czmax, and Csrv together in one cell array
%       suitable for passing to tableplot function
C = cell(ngrp,maxgrplen);
for igrp = 1:ngrp
    ngstn = length(grplst{igrp});
    for istn = 1:ngstn
        C{igrp,istn}={Csrv{igrp,istn},Czmax{igrp,istn},Cbathy{igrp,istn}}';
    end
    clear ngstn;
end
Clab = {'Srv#: Min-Max(-Missing)'; 'z_{max} [m]: Medn(Min-Max)'; ...
    'z_{bthy} [m]'};

%% printable table of results
tableplot(grplst,C,Clab);
eval(sprintf('print -dpng plt/StnSummaries%s;',runname));
delete(gcf);

% plot showing station names
b = load(bathyfil);
c = load(cstfil);
figport('on');
b.z(isnan(b.z)) = 0;
imagesc(b.lon,flipud(b.lat),b.z);
colormap('gray')
set(gca,'ydir','normal');
hold;
plot(c.lon,c.lat,'k');
lonbuf = 0.08*(max(STN.Lon) - min(STN.Lon));
set(gca,'xlim',[min(STN.Lon) max(STN.Lon)+lonbuf]);
latbuf = 0.08*(max(STN.Lat) - min(STN.Lat));
set(gca,'ylim',[min(STN.Lat) max(STN.Lat)+latbuf]);
for istn = 1:nstn
    plot(STN.Lon(istn),STN.Lat(istn),'k.');
    text(STN.Lon(istn),STN.Lat(istn),sprintf(' %s',STN.Stn{istn}),...
        'fontsize',6,'rotation',40,'Interpreter','none','color','r');
end
clear istn;
print -dpng plt/stationnames;
delete(gcf);

% plot showing first/last/missing survey numbers
figport('on');
imagesc(b.lon,flipud(b.lat),b.z);
colormap('gray')
set(gca,'ydir','normal');
hold;
plot(c.lon,c.lat,'k');
set(gca,'xlim',[min(STN.Lon) max(STN.Lon)+lonbuf]);
set(gca,'ylim',[min(STN.Lat) max(STN.Lat)+latbuf]);
for istn = 1:nstn
    plot(STN.Lon(istn),STN.Lat(istn),'k.');
    text(STN.Lon(istn),STN.Lat(istn),sprintf(' %d-%d(%d)',...
    firstsrvind(istn),lastsrvind(istn),missingsrvind(istn)),...
        'fontsize',6,'rotation',40,'Interpreter','none','color','r');
end
clear istn buf;
print -dpng plt/surveys;
delete(gcf);

% plot showing median/min/max of zmax
figport('on');
imagesc(b.lon,flipud(b.lat),b.z);
colormap('gray')
set(gca,'ydir','normal');
hold;
plot(c.lon,c.lat,'k');
set(gca,'xlim',[min(STN.Lon) max(STN.Lon)+lonbuf]);
set(gca,'ylim',[min(STN.Lat) max(STN.Lat)+latbuf]);
for istn = 1:nstn
    plot(STN.Lon(istn),STN.Lat(istn),'k.');
    text(STN.Lon(istn),STN.Lat(istn),sprintf('%.1fm(%.1f/%.1f)',...
    STN.zmaxMedn(istn),STN.zmaxMin(istn),STN.zmaxMax(istn)),...
        'fontsize',6,'rotation',40,'Interpreter','none','color','r');
end
clear istn buf;
print -dpng plt/zmax;
delete(gcf);

%% Rank Plots
RnkPlts;

% end of module
diary off;